+++
title = "TOC :target"
description = "Test the `#+toc` keyword with `:target` attribute"
tags = ["keyword", "toc", "target"]
draft = false
+++

`ox-hugo` Issue #[393](https://github.com/kaushalmodi/ox-hugo/issues/393)


## Reading {#reading-material}


### landing page {#landing-page}

<div class="ox-hugo-toc toc">
<div></div>

<div class="heading">Table of Contents</div>

- [landing page](#landing-page)
- [first subsection in Reading](#first-subsection-in-reading)

</div>
<!--endtoc-->


### first subsection in Reading {#first-subsection-in-reading}


## Example from Org Manual {#example-from-org-manual}

[Reference](https://orgmode.org/manual/Table-of-Contents.html)


### Target {#TargetSection}


#### Heading A {#heading-a}


#### Heading B {#heading-b}


### Another section {#another-section}

<div class="ox-hugo-toc toc">
<div></div>

<div class="heading">Table of Contents</div>

- [Heading A](#heading-a)
- [Heading B](#heading-b)

</div>
<!--endtoc-->
